package com.gic.haoban.manage.service.service.out.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.fastjson.JSONObject;
import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.ServiceResponse;
import com.gic.haoban.manage.api.dto.AuditDTO;
import com.gic.haoban.manage.api.dto.StaffClerkInfoDTO;
import com.gic.haoban.manage.api.dto.StaffClerkRelationDTO;
import com.gic.haoban.manage.api.enums.AuditType;
import com.gic.haoban.manage.api.service.AuditApiService;
import com.gic.haoban.manage.api.service.StaffClerkRelationApiService;
import com.gic.haoban.manage.service.dao.mapper.TabHaobanStaffClerkRelationMapper;
import com.gic.haoban.manage.service.entity.TabHaobanStaffClerkRelation;
import com.gic.haoban.manage.service.service.StaffClerkRelationService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StaffClerkRelationApiServiceImpl implements StaffClerkRelationApiService {

	private static final Logger logger= LoggerFactory.getLogger(StaffClerkRelationApiServiceImpl.class);

	@Autowired
	private StaffClerkRelationService staffClerkRelatinService;

	@Autowired
	private EnterpriseService enterpriseService;

	@Autowired
	private ClerkService clerkService;

	@Autowired
	private StoreService storeService;
	@Autowired
	private TabHaobanStaffClerkRelationMapper tabHaobanStaffClerkRelationMapper;

	@Autowired
	private AuditApiService auditApiService;


	@Override
	public List<StaffClerkRelationDTO> listBindCode(String enterpriseId, Set<String> clerkCodeList) {
		return staffClerkRelatinService.listBindCode(enterpriseId,clerkCodeList);
	}
	@Override
	public List<StaffClerkRelationDTO> listBindCodeByStaffId(List<String> enterpriseIdList, String staffId) {
		return staffClerkRelatinService.listBindCodeByStaffId(enterpriseIdList,staffId);
	}

	@Override
	public List<StaffClerkInfoDTO> listBindDetailByStaffId(String staffId) {
		List<StaffClerkRelationDTO> list = staffClerkRelatinService.listBindCodeByStaffId(null, staffId);
		if (CollectionUtils.isEmpty(list)) {
			return null;
		}
		List<StaffClerkInfoDTO> infoDTOS = EntityUtil.changeEntityListByJSON(StaffClerkInfoDTO.class, list);
		Map<String,String> nameMap=new HashMap<>();
		infoDTOS.forEach(infoDTO->{
			//企业
			if (!nameMap.containsKey(infoDTO.getEnterpriseId())) {
				EnterpriseDTO enterpriseDTO = enterpriseService.getEnterpriseById(infoDTO.getEnterpriseId());
				if (null != enterpriseDTO) {
					nameMap.put(infoDTO.getEnterpriseId(),enterpriseDTO.getEnterpriseName());
				}else{
					nameMap.put(infoDTO.getEnterpriseId(),"未知商户");
				}
			}
			//门店店员名称
			if (!nameMap.containsKey(infoDTO.getClerkId())) {
				ClerkDTO clerkDTO = clerkService.getClerkByClerkId(infoDTO.getClerkId());
				if (null != clerkDTO) {
					nameMap.put(infoDTO.getClerkId(),clerkDTO.getClerkName());
					nameMap.put(infoDTO.getStoreId(),clerkDTO.getStoreName());
					infoDTO.setClerkPhoneNumber(clerkDTO.getPhoneNumber());
				}else{
					nameMap.put(infoDTO.getEnterpriseId(),"未知店员");
				}
			}

			//门店店员名称
			if (!nameMap.containsKey(infoDTO.getStoreId())) {
				StoreDTO storeDTO = storeService.getStore(infoDTO.getStoreId());
				if (null != storeDTO) {
					nameMap.put(infoDTO.getStoreId(),storeDTO.getStoreName());
				}else{
					nameMap.put(infoDTO.getStoreId(),"未知门店");
				}
			}

			infoDTO.setClerkName(nameMap.get(infoDTO.getClerkId()));
			infoDTO.setStoreName(nameMap.get(infoDTO.getStoreId()));
			infoDTO.setEnterpriseName(nameMap.get(infoDTO.getEnterpriseId()));
		});
		return infoDTOS;
	}

	@Override
	public ServiceResponse bindStaffClerk(StaffClerkRelationDTO staffClerkRelationDTO) {
		logger.info("绑定clerk:{}", JSONObject.toJSONString(staffClerkRelationDTO));
		ServiceResponse<Object> response = new ServiceResponse<>();
		StaffClerkRelationDTO relationDTO = staffClerkRelatinService.getBindByClerkId(staffClerkRelationDTO.getClerkId(), staffClerkRelationDTO.getWxEnterpriseId());
		if (null!=relationDTO) {
			response.setCode(2);
			response.setMessage("已经被绑定，不能绑定");
			return response;
		}
		AuditDTO auditDTO = auditApiService.findByBindRelatedIdAndAuditType(staffClerkRelationDTO.getClerkId(), AuditType.CLERK_BIND.getCode());
		if (null != auditDTO) {
			response.setCode(4);
			response.setMessage("该导购已经被被申请绑定，请审核处理后再绑定");
			return response;
		}
		StaffClerkRelationDTO storeHasBind = staffClerkRelatinService.getOneBindByStoreId(staffClerkRelationDTO.getStaffId(), staffClerkRelationDTO.getStoreId());
		if (storeHasBind!=null) {
			response.setCode(3);
			response.setMessage("该导购已在该门店下有其它成员绑定");
			return response;
		}

		staffClerkRelatinService.bind(staffClerkRelationDTO);
		return response;
	}
	
	@Override
	public StaffClerkRelationDTO getByCodeAndEnterpriseId(String clerkCode, String enterpriseId) {
		return staffClerkRelatinService.getByCodeAndEnterpriseId(clerkCode,enterpriseId);
	}
	@Override
	public String insert(StaffClerkRelationDTO staffClerkRelation) {
		return staffClerkRelatinService.insert(staffClerkRelation);
	}
	@Override
	public String delByStoreIdAndCode(String storeId, String clerkCode) {
		tabHaobanStaffClerkRelationMapper.delByStoreIdAndCode(storeId,clerkCode);
		return null;
	}
	@Override
	public List<StaffClerkRelationDTO> listByClerkIds(List<String> clerkIds) {
		List<TabHaobanStaffClerkRelation> list = tabHaobanStaffClerkRelationMapper.listByClerkIds(clerkIds);
		if(CollectionUtil.isEmpty(list)){
			return new ArrayList<StaffClerkRelationDTO>();
		}
		List<StaffClerkRelationDTO> result = EntityUtil.changeEntityListByJSON(StaffClerkRelationDTO.class, list);
		return result;
	}
	@Override
	public List<StaffClerkRelationDTO> listByStoreId(String storeId) {
		List<TabHaobanStaffClerkRelation> list = tabHaobanStaffClerkRelationMapper.listByStoreId(storeId);
		if(CollectionUtil.isEmpty(list)){
			return new ArrayList<StaffClerkRelationDTO>();
		}
		List<StaffClerkRelationDTO> result = EntityUtil.changeEntityListByJSON(StaffClerkRelationDTO.class, list);
		return result;	
	}

	@Override
	public boolean unbindByStaffAndClerkId(String staffId, String clerkId) {
		boolean b = staffClerkRelatinService.delBind(clerkId);
		return b;
	}
}
