package com.gic.haoban.manage.service.service.out.impl;

import java.util.Date;
import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.dto.GicTreeDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.enterprise.api.service.StoreGroupService;
import com.gic.haoban.common.utils.UuidUtil;
import com.gic.haoban.manage.api.dto.EnterpriseDetailDTO;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.service.dao.mapper.StaffMapper;
import com.gic.haoban.manage.service.dao.mapper.WxEnterpriseRelatedMapper;
import com.gic.haoban.manage.service.entity.TabHaobanStaff;
import com.gic.haoban.manage.service.entity.TabHaobanWxEnterpriseRelated;
import com.gic.haoban.manage.service.service.DepartmentService;
import com.gic.haoban.manage.service.service.StaffService;
import com.gic.haoban.manage.service.service.WxEnterpriseRelatedService;

@Service
public class WxEnterpriseRelatedApiServiceImpl implements WxEnterpriseRelatedApiService {
    private static final Logger logger = LogManager.getLogger(WxEnterpriseRelatedApiServiceImpl.class);
    @Autowired
	private WxEnterpriseRelatedMapper wxEnterpriseRelatedMapper;
	@Autowired
	private WxEnterpriseRelatedService wxEnterpriseRelatedService;
	@Autowired
	private StoreGroupService storeGroupService;
	@Autowired
	private DepartmentService departmentService;
	@Autowired
	private StaffService staffService;
	@Autowired
	private StaffMapper staffMapper;
	@Override
	public List<EnterpriseDetailDTO> listEnterpriseByWxEnterpriseId(
			String wxEnterpriseId) {
		
		List<TabHaobanWxEnterpriseRelated> relatedList = wxEnterpriseRelatedMapper.listByWxenterpriseId(wxEnterpriseId);
		List<EnterpriseDetailDTO> result = EntityUtil.changeEntityListByJSON(EnterpriseDetailDTO.class, relatedList);
		for (EnterpriseDetailDTO enterpriseDetailDTO : result) {
			String enterpriseId = enterpriseDetailDTO.getEnterpriseId();
			int gicAllCount = storeGroupService.gicDepartmentCount(enterpriseId);
			int syncCount = departmentService.countSyncDepartmentByEnterpriseId(enterpriseId);
			logger.info("【企业数量】gicAllCount={},syncCount={}",gicAllCount,syncCount);
			int nodeCount = gicAllCount - syncCount;
			enterpriseDetailDTO.setNodeCount(nodeCount);
		}
		return result;
	}
	
//	public int getNodeCount(String enterpriseId,String parentId,int type) {
//		int nodeCount = 0;
//		List<GicTreeDTO> departmentList = storeGroupService.listGicTree(enterpriseId,type, parentId);
//		for (GicTreeDTO gicTreeDTO : departmentList) {
//			if(departmentService.getByRelatedId(gicTreeDTO.getId()) == null) {
//				nodeCount ++;
//			}
//			List<GicTreeDTO> departmentList2 = storeGroupService.listGicTree(enterpriseId,gicTreeDTO.getType(), gicTreeDTO.getId());
//			while(!departmentList2.isEmpty()) {
//				for (GicTreeDTO gicTreeDTO2 : departmentList) {
//					nodeCount += getNodeCount(enterpriseId,gicTreeDTO2.getId(),gicTreeDTO2.getType());
//				}
//			}
//		}
//		
//		return nodeCount;
//		
//	}
	@Override
	public int wxEnterpriseBind(String enterpriseId, String wxEnterpriseId,
			String version) {
		TabHaobanWxEnterpriseRelated tab = wxEnterpriseRelatedMapper.findOneByEnterpriseId(enterpriseId);
		if(tab!= null){
			logger.info("该gicEnterpriseId已经绑定过了");
			return 1;
		}else{
			 tab = new TabHaobanWxEnterpriseRelated();
			 tab.setEnterpriseId(enterpriseId);
			 tab.setWxEnterpriseId(wxEnterpriseId);
			 tab.setStatusFlag(1);
			 tab.setVersion(version);
			 tab.setCreateTime(new Date());
			 tab.setUpdateTime(new Date());
			 tab.setWxEnterpriseRelatedId(UuidUtil.randomUUID());
			 wxEnterpriseRelatedMapper.insertSelective(tab);
			 
			 TabHaobanStaff sStaff = staffMapper.selectSuperByWxEnterpriseId(wxEnterpriseId);
			 if(sStaff == null){
				 TabHaobanStaff staff = new TabHaobanStaff();
				 staff.setStaffName("超级管理员");
				 staff.setWxEnterpriseId(wxEnterpriseId);
				 staff.setSuperManagerFlag(1);
				 staffService.add(staff);
			 }
		}
		return 0;
	}
	@Override
	public String getGicEnterpriseIdByEnterpriseRelatedId(String wxEnterpriseRelatedId) {
		TabHaobanWxEnterpriseRelated tab = wxEnterpriseRelatedService.getByGicEnterpriseIdByEnterpriseRelatedId(wxEnterpriseRelatedId);
		if(tab != null) {
			return tab.getEnterpriseId();
		}
		
		return null;
	}

	@Override
	public boolean enterpriseUseNew(String enterpriseId) {
		TabHaobanWxEnterpriseRelated tab = wxEnterpriseRelatedMapper.findOneByEnterpriseId(enterpriseId);
		if(tab == null){
			return false;
		}
		return true;
	}

	@Override
	public EnterpriseDetailDTO getByEnterpriseId(String enterpriseId) {
		TabHaobanWxEnterpriseRelated tab = wxEnterpriseRelatedMapper.findOneByEnterpriseId(enterpriseId);
		EnterpriseDetailDTO detail = EntityUtil.changeEntityByJSON(EnterpriseDetailDTO.class, tab);
		return detail;
	}

	@Override
	public List<EnterpriseDetailDTO> queryAllHasGicEnterpriseId() {
		List<TabHaobanWxEnterpriseRelated> relatedList = wxEnterpriseRelatedMapper.queryAllHasGicEnterpriseId();
		List<EnterpriseDetailDTO> result = EntityUtil.changeEntityListByJSON(EnterpriseDetailDTO.class, relatedList);
		for (EnterpriseDetailDTO enterpriseDetailDTO : result) {
			String enterpriseId = enterpriseDetailDTO.getEnterpriseId();
			int gicAllCount = storeGroupService.gicDepartmentCount(enterpriseId);
			int syncCount = departmentService.countSyncDepartmentByEnterpriseId(enterpriseId);
			int nodeCount = gicAllCount - syncCount;
			enterpriseDetailDTO.setNodeCount(nodeCount);
		}
		return result;
	}

	@Override
	public List<EnterpriseDetailDTO> listEnterpriseByEnterpriseIds(
			List<String> enterpriseIds) {
		List<TabHaobanWxEnterpriseRelated> list= wxEnterpriseRelatedMapper.listEnterpriseByEnterpriseIds(enterpriseIds);
		List<EnterpriseDetailDTO> details = EntityUtil.changeEntityListByJSON(EnterpriseDetailDTO.class, list);
		return details;	
	}

	@Override
	public List<EnterpriseDetailDTO> queryBindGicEnterpriseByTime(String seqTime) {
		List<TabHaobanWxEnterpriseRelated> list= wxEnterpriseRelatedMapper.listEnterpriseByTime(seqTime);
		List<EnterpriseDetailDTO> details = EntityUtil.changeEntityListByJSON(EnterpriseDetailDTO.class, list);
		return details;
	}
}
